pycustos |Build Status|
=======================

*Quis custodiet ipsos custodes?*

.. figure:: https://raw.githubusercontent.com/fact-project/pycustos/master/resources/custodian.jpg
   :alt: https://raw.githubusercontent.com/fact-project/pycustos/master/resources/custodian.jpg

   https://raw.githubusercontent.com/fact-project/pycustos/master/resources/custodian.jpg

A framework to monitor complex systems and send alerts. Taking logging
to the next step.

.. |Build Status| image:: https://travis-ci.org/fact-project/pycustos.svg?branch=master
   :target: https://travis-ci.org/fact-project/pycustos
